==> scat-0.0.6.tar.gz: scat-0.0.6/createnode.lisp <==
;;;; S-expr Cluster Administration Toolkit (SCAT)
;;;; Copyright (C) 2007 James Earl Prewett

;;;; This program is free software; you can redistribute it and/or
;;;; modify it under the terms of the GNU General Public License
;;;; as published by the Free Software Foundation; either version 2
;;;; of the License, or (at your option) any later version.
;;;;
;;;; This program is distributed in the hope that it will be useful,
;;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;;; GNU General Public License for more details.
;;;;
;;;; You should have received a copy of the GNU General Public License
;;;; along with this program; if not, write to the Free Software
;;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(defpackage :edu.unm.hpc.Scat.create-node
  (:nicknames :Scat.create-node)
  (:use :cl
        #+allegro :clos
        #+cmu :pcl
        #+sbcl :sb-mop
        #+lispworks :hcl
        :cl-user
        :cl-cli
        :Scat.Lib
        ))

(in-package :edu.unm.hpc.Scat.create-node)

(defvar *node* ())
(defvar *mac* ())
(defvar *state* ())

(defvar *opts* 
  (list
   (make-instance 'cli-opt
                  :name "help"
                  :arguments ()
                  :action
                  #'(lambda ()
                      (progn
                        (org.prewett.cl-cli::help *opts*)
                        (cl-user::quit)))
                  :description "display this help text")
   (make-instance 'cli-opt
                  :name :default
                  :arguments '(node mac type &optional state)
                  :action
                  #'(lambda (node mac type &optional (state "install"))
                      (format t "n: ~A m: ~A s: ~A~%"
                              node mac state)
                      (setf *node* node
                            *mac* 
                            (format () "01-~A" 
                                    (cl-ppcre:regex-replace-all 
                                     ":" 
                                     (string-downcase mac) 
                                     "-"))
                            *state* state)))))

(defun toplevel () 
  (read-scat-config)
  (cl-cli::process-options *opts* (rest sb-ext:*posix-argv*))

  (format t "node: ~A mac: ~A state: ~A ~%" 
          *node* *mac* *state*)
  (add-node *node* (string-downcase *state*) *mac*)
  (set-state *node* (string-downcase *state*))
  (name-mac *mac* *node*)
  (cl-user::quit))

==> scat-0.0.9.tar.gz: scat-0.0.9/createnode.lisp <==
;;;; S-expr Cluster Administration Toolkit (SCAT)
;;;; Copyright (C) 2007 James Earl Prewett

;;;; This program is free software; you can redistribute it and/or
;;;; modify it under the terms of the GNU General Public License
;;;; as published by the Free Software Foundation; either version 2
;;;; of the License, or (at your option) any later version.
;;;;
;;;; This program is distributed in the hope that it will be useful,
;;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;;; GNU General Public License for more details.
;;;;
;;;; You should have received a copy of the GNU General Public License
;;;; along with this program; if not, write to the Free Software
;;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

(defpackage :edu.unm.hpc.Scat.create-node
  (:nicknames :Scat.create-node)
  (:use :cl
        #+allegro :clos
        #+cmu :pcl
        #+sbcl :sb-mop
        #+lispworks :hcl
        :cl-user
        :cl-cli
        :Scat.Lib
        ))

(in-package :edu.unm.hpc.Scat.create-node)

(defvar *node* ())
(defvar *mac* ())
(defvar *state* ())

(defvar *opts* 
  (list
   (make-instance 'cli-opt
                  :name "help"
                  :arguments ()
                  :action
                  #'(lambda ()
                      (progn
                        (org.prewett.cl-cli::help *opts*)
                        (cl-user::quit)))
                  :description "display this help text")
   (make-instance 'cli-opt
                  :name :default
                  :arguments '(node mac type &optional state)
                  :action
                  #'(lambda (node mac type &optional (state "install"))
                      (setf *node* node
                            *mac* 
                            (format () "01-~A" 
                                    (cl-ppcre:regex-replace-all 
                                     ":" 
                                     (string-downcase mac) 
                                     "-"))
                            *type* type
                            *state* state)))))

(defun toplevel () 
  (read-scat-config)
  (cl-cli::process-options *opts* (rest sb-ext:*posix-argv*))

  (format t "node: ~A mac: ~A state: ~A ~%" 
          *node* *mac* *state*)
  (set-state *node* (string-downcase *state*) t)
  (name-mac *mac* *node*)
  (set-type *node* *type*)
  (cl-user::quit))
